==> activity-center-biz-1.2.9.8.transfer-20161118.085627-1-sources.jar: cn/com/duiba/activity/center/biz/kafka/callback/LittleGameCutCreditsCallback.java <==

package cn.com.duiba.activity.center.biz.kafka.callback;

import java.util.Arrays;
import java.util.Collections;
import java.util.Properties;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.ThreadFactory;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.apache.kafka.clients.consumer.OffsetAndMetadata;
import org.apache.kafka.common.TopicPartition;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import cn.com.duiba.activity.center.biz.kafka.KafkaClient;
import cn.com.duiba.activity.center.biz.kafka.TopicConstant;
import cn.com.duiba.activity.center.biz.plugin.buckle.ConsumerCutCreditsService;
import cn.com.duiba.order.center.api.dto.CreditsCallbackMessage;

import com.alibaba.fastjson.JSONObject;

/**
 * describe : 小游戏扣积分回调接口
 * @author  : cdm
 * @date    : 2016年11月2日 下午3:41:47
 */
@Service
public class LittleGameCutCreditsCallback implements InitializingBean{
    
    private static Logger log = LoggerFactory.getLogger(LittleGameCutCreditsCallback.class);

    @Autowired
    private KafkaClient kafkaClient;
    @Autowired
    private TopicConstant topicConstant;
    @Autowired
    private ConsumerCutCreditsService consumerCutCreditsService;
    /**
     * 消费线程数
     */
    private static int pool = 3;
    private ExecutorService executorService;

    public void start() {
        if (executorService != null) {
            return;
        }
        executorService = Executors.newFixedThreadPool(pool,new ThreadFactory() {
            private int i = 0;

            @Override
            public Thread newThread(Runnable runnable) {
                return new Thread(runnable, "Thread-Activity-ConsumerCredits-" + (i++));
            }
        });
        for (int i = 0; i < pool; i++) {
            executorService.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        Properties props = new Properties();
                        props.put("bootstrap.servers", kafkaClient.getBootstrapServers());
                        props.put("group.id", "credits_consumer");
                        props.put("enable.auto.commit", "false");
                        props.put("session.timeout.ms", "30000");
                        props.put("auto.offset.reset", "earliest");
                        props.put("key.deserializer", "org.apache.kafka.common.serialization.StringDeserializer");
                        props.put("value.deserializer", "org.apache.kafka.common.serialization.StringDeserializer");
                        KafkaConsumer<String, String> consumer = new KafkaConsumer<String, String>(props);
                        consumer.subscribe(Arrays.asList(topicConstant.getTopicLittleGameCutCreditsResponse()));//"littleGameSubCallbackDevABC"));//
                        while (true) {
                            if (Thread.currentThread().isInterrupted()) {
                                break;
                            }
                            ConsumerRecords<String, String> records = consumer.poll(100);
                            for (TopicPartition pt : records.partitions()) {
                                for (ConsumerRecord<String, String> record : records.records(pt)) {
                                    try {
                                        CreditsCallbackMessage response = JSONObject.parseObject(record.value(), CreditsCallbackMessage.class);
                                        consumerCutCreditsService.creditsCallback(response);
                                    } catch (Exception e) {
                                        log.error("activity consumer credits error:", e);
                                    } finally {
                                        long lastOffset = record.offset();
                                        consumer.commitSync(Collections.singletonMap(pt, new OffsetAndMetadata(lastOffset + 1)));
                                    }
                                }
                            }
                        }
                        consumer.close();
                    } catch (Exception e) {
                        log.error("error:", e);
                    }
                }
            });
        }
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        start();
    }

}

==> activity-center-biz-1.2.9.11.transfer-20161118.093154-1-sources.jar: cn/com/duiba/activity/center/biz/kafka/callback/LittleGameCutCreditsCallback.java <==

package cn.com.duiba.activity.center.biz.kafka.callback;

import java.util.Arrays;
import java.util.Collections;
import java.util.Properties;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.ThreadFactory;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.apache.kafka.clients.consumer.ConsumerRecords;
import org.apache.kafka.clients.consumer.KafkaConsumer;
import org.apache.kafka.clients.consumer.OffsetAndMetadata;
import org.apache.kafka.common.TopicPartition;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import cn.com.duiba.activity.center.biz.kafka.KafkaClient;
import cn.com.duiba.activity.center.biz.kafka.TopicConstant;
import cn.com.duiba.activity.center.biz.plugin.buckle.ConsumerCutCreditsService;
import cn.com.duiba.order.center.api.dto.CreditsCallbackMessage;

import com.alibaba.fastjson.JSONObject;

/**
 * describe : 小游戏扣积分回调接口
 * @author  : cdm
 * @date    : 2016年11月2日 下午3:41:47
 */
@Service
public class LittleGameCutCreditsCallback implements InitializingBean{
    
    private static Logger log = LoggerFactory.getLogger(LittleGameCutCreditsCallback.class);

    @Autowired
    private KafkaClient kafkaClient;
    @Autowired
    private TopicConstant topicConstant;
    @Autowired
    private ConsumerCutCreditsService consumerCutCreditsService;
    private ExecutorService executorService;

    public void start() {
        if (executorService != null) {
            return;
        }
        /*
      消费线程数
     */
        int pool = 3;
        executorService = Executors.newFixedThreadPool(pool,new ThreadFactory() {
            private int i = 0;

            @Override
            public Thread newThread(Runnable runnable) {
                return new Thread(runnable, "Thread-Activity-ConsumerCredits-" + (i++));
            }
        });
        for (int i = 0; i < pool; i++) {
            executorService.submit(new Runnable() {
                @Override
                public void run() {
                    try {
                        Properties props = new Properties();
                        props.put("bootstrap.servers", kafkaClient.getBootstrapServers());
                        props.put("group.id", "credits_consumer");
                        props.put("enable.auto.commit", "false");
                        props.put("session.timeout.ms", "30000");
                        props.put("auto.offset.reset", "earliest");
                        props.put("key.deserializer", "org.apache.kafka.common.serialization.StringDeserializer");
                        props.put("value.deserializer", "org.apache.kafka.common.serialization.StringDeserializer");
                        KafkaConsumer<String, String> consumer = new KafkaConsumer<String, String>(props);
                        consumer.subscribe(Collections.singletonList(topicConstant.getTopicLittleGameCutCreditsResponse()));//"littleGameSubCallbackDevABC"));//
                        while (true) {
                            if (Thread.currentThread().isInterrupted()) {
                                break;
                            }
                            ConsumerRecords<String, String> records = consumer.poll(100);
                            for (TopicPartition pt : records.partitions()) {
                                for (ConsumerRecord<String, String> record : records.records(pt)) {
                                    try {
                                        CreditsCallbackMessage response = JSONObject.parseObject(record.value(), CreditsCallbackMessage.class);
                                        consumerCutCreditsService.creditsCallback(response);
                                    } catch (Exception e) {
                                        log.error("activity consumer credits error:", e);
                                    } finally {
                                        long lastOffset = record.offset();
                                        consumer.commitSync(Collections.singletonMap(pt, new OffsetAndMetadata(lastOffset + 1)));
                                    }
                                }
                            }
                        }
                        consumer.close();
                    } catch (Exception e) {
                        log.error("error:", e);
                    }
                }
            });
        }
    }

    @Override
    public void afterPropertiesSet() throws Exception {
        start();
    }

}
